"""Tests for single server boot ups."""

from .mtt_tc import MTTClusterTC
from socket import gethostbyname, gethostname


class BootUpTC(MTTClusterTC):
    """Single server boot tests."""

    async def test_default_boot(self):
        """Does the server default boot on http://localhost:3000?"""
        await self.create_server_with_flags()
        def tests(response):
            """Response tests."""
            self.assertEqual(response.status, 200)
        await self.run_tests("/", tests)

    async def test_alt_port_boot(self):
        """Can the server boot off on alternate port?"""
        port = 9025
        await self.create_server_with_flags("-p", str(port))
        def tests(response):
            """Response tests."""
            self.assertEqual(response.status, 200)
        await self.run_tests("/", tests)

    async def test_alt_address_boot(self):
        """Can it boot off an alternate address?"""
        addr = gethostbyname(gethostname())
        await self.create_server_with_flags("-a", addr)
        def tests(response):
            """Response tests."""
            self.assertEqual(response.status, 200)
        await self.run_tests("/", tests)

    async def test_for_session_id(self):
        await self.create_server()
        def tests(response):
            """Response tests."""
            self.assertEqual(response.status, 200)
        await self.run_tests("/", tests)
        self.assertEqual(len(self.jar), 1, "There should be a session id.")
